@@ -1,32 +1,32 @@
 -- cPanel mysql backup
 GRANT USAGE ON *.* TO 'uuism'@'172.31.13.215' IDENTIFIED BY PASSWORD '*4DAF2F2129D8E11A627F7BBD9BB97CE832DFC325';
-GRANT ALL PRIVILEGES ON `uuism\_test`.* TO 'uuism'@'172.31.13.215';
 GRANT ALL PRIVILEGES ON `uuism\_joom675`.* TO 'uuism'@'172.31.13.215';
-GRANT ALL PRIVILEGES ON `uuism\_whmcs`.* TO 'uuism'@'172.31.13.215';
+GRANT ALL PRIVILEGES ON `uuism\_test`.* TO 'uuism'@'172.31.13.215';
 GRANT ALL PRIVILEGES ON `uuism\_mw1980`.* TO 'uuism'@'172.31.13.215';
+GRANT ALL PRIVILEGES ON `uuism\_whmcs`.* TO 'uuism'@'172.31.13.215';
 GRANT ALL PRIVILEGES ON `uuism\_net\_wikidb`.* TO 'uuism'@'172.31.13.215';
 GRANT USAGE ON *.* TO 'uuism'@'172.31.2.117' IDENTIFIED BY PASSWORD '*4DAF2F2129D8E11A627F7BBD9BB97CE832DFC325';
 GRANT ALL PRIVILEGES ON `cptmpdb\_uuism\_MHMX4VxwNGzwGfz4`.* TO 'uuism'@'172.31.2.117';
 GRANT ALL PRIVILEGES ON `uuism\_joom675`.* TO 'uuism'@'172.31.2.117';
 GRANT ALL PRIVILEGES ON `uuism\_test`.* TO 'uuism'@'172.31.2.117';
-GRANT ALL PRIVILEGES ON `uuism\_mw1980`.* TO 'uuism'@'172.31.2.117';
 GRANT ALL PRIVILEGES ON `uuism\_whmcs`.* TO 'uuism'@'172.31.2.117';
+GRANT ALL PRIVILEGES ON `uuism\_mw1980`.* TO 'uuism'@'172.31.2.117';
 GRANT ALL PRIVILEGES ON `uuism\_net\_wikidb`.* TO 'uuism'@'172.31.2.117';
 GRANT USAGE ON *.* TO 'uuism'@'184.76.96.122' IDENTIFIED BY PASSWORD '*4DAF2F2129D8E11A627F7BBD9BB97CE832DFC325';
-GRANT ALL PRIVILEGES ON `uuism\_test`.* TO 'uuism'@'184.76.96.122';
 GRANT ALL PRIVILEGES ON `uuism\_joom675`.* TO 'uuism'@'184.76.96.122';
+GRANT ALL PRIVILEGES ON `uuism\_test`.* TO 'uuism'@'184.76.96.122';
 GRANT ALL PRIVILEGES ON `uuism\_mw1980`.* TO 'uuism'@'184.76.96.122';
 GRANT ALL PRIVILEGES ON `uuism\_whmcs`.* TO 'uuism'@'184.76.96.122';
 GRANT ALL PRIVILEGES ON `uuism\_net\_wikidb`.* TO 'uuism'@'184.76.96.122';
 GRANT USAGE ON *.* TO 'uuism'@'24.107.80.156' IDENTIFIED BY PASSWORD '*4DAF2F2129D8E11A627F7BBD9BB97CE832DFC325';
-GRANT ALL PRIVILEGES ON `uuism\_test`.* TO 'uuism'@'24.107.80.156';
 GRANT ALL PRIVILEGES ON `uuism\_joom675`.* TO 'uuism'@'24.107.80.156';
-GRANT ALL PRIVILEGES ON `uuism\_whmcs`.* TO 'uuism'@'24.107.80.156';
+GRANT ALL PRIVILEGES ON `uuism\_test`.* TO 'uuism'@'24.107.80.156';
 GRANT ALL PRIVILEGES ON `uuism\_mw1980`.* TO 'uuism'@'24.107.80.156';
+GRANT ALL PRIVILEGES ON `uuism\_whmcs`.* TO 'uuism'@'24.107.80.156';
 GRANT ALL PRIVILEGES ON `uuism\_net\_wikidb`.* TO 'uuism'@'24.107.80.156';
-GRANT USAGE ON *.* TO 'uuism'@'34.237.106.38' IDENTIFIED BY PASSWORD '*36C4F4D7B73FA9A5AEB957176D1F68418B9681D9';
-GRANT ALL PRIVILEGES ON `uuism\_joom675`.* TO 'uuism'@'34.237.106.38';
+GRANT USAGE ON *.* TO 'uuism'@'34.237.106.38' IDENTIFIED BY PASSWORD '*4DAF2F2129D8E11A627F7BBD9BB97CE832DFC325';
 GRANT ALL PRIVILEGES ON `cptmpdb\_uuism\_MHMX4VxwNGzwGfz4`.* TO 'uuism'@'34.237.106.38';
+GRANT ALL PRIVILEGES ON `uuism\_joom675`.* TO 'uuism'@'34.237.106.38';
 GRANT ALL PRIVILEGES ON `uuism\_test`.* TO 'uuism'@'34.237.106.38';
 GRANT ALL PRIVILEGES ON `uuism\_mw1980`.* TO 'uuism'@'34.237.106.38';
 GRANT ALL PRIVILEGES ON `uuism\_whmcs`.* TO 'uuism'@'34.237.106.38';
@@ -38,16 +38,16 @@ GRANT ALL PRIVILEGES ON `uuism\_mw1980`.* TO 'uuism'@'52.87.69.75';
 GRANT ALL PRIVILEGES ON `uuism\_whmcs`.* TO 'uuism'@'52.87.69.75';
 GRANT ALL PRIVILEGES ON `uuism\_net\_wikidb`.* TO 'uuism'@'52.87.69.75';
 GRANT USAGE ON *.* TO 'uuism'@'65.18.172.20' IDENTIFIED BY PASSWORD '*4DAF2F2129D8E11A627F7BBD9BB97CE832DFC325';
-GRANT ALL PRIVILEGES ON `uuism\_joom675`.* TO 'uuism'@'65.18.172.20';
 GRANT ALL PRIVILEGES ON `uuism\_test`.* TO 'uuism'@'65.18.172.20';
-GRANT ALL PRIVILEGES ON `uuism\_mw1980`.* TO 'uuism'@'65.18.172.20';
+GRANT ALL PRIVILEGES ON `uuism\_joom675`.* TO 'uuism'@'65.18.172.20';
 GRANT ALL PRIVILEGES ON `uuism\_whmcs`.* TO 'uuism'@'65.18.172.20';
+GRANT ALL PRIVILEGES ON `uuism\_mw1980`.* TO 'uuism'@'65.18.172.20';
 GRANT ALL PRIVILEGES ON `uuism\_net\_wikidb`.* TO 'uuism'@'65.18.172.20';
 GRANT USAGE ON *.* TO 'uuism'@'65.18.196.199' IDENTIFIED BY PASSWORD '*4DAF2F2129D8E11A627F7BBD9BB97CE832DFC325';
-GRANT ALL PRIVILEGES ON `uuism\_test`.* TO 'uuism'@'65.18.196.199';
 GRANT ALL PRIVILEGES ON `uuism\_joom675`.* TO 'uuism'@'65.18.196.199';
-GRANT ALL PRIVILEGES ON `uuism\_mw1980`.* TO 'uuism'@'65.18.196.199';
+GRANT ALL PRIVILEGES ON `uuism\_test`.* TO 'uuism'@'65.18.196.199';
 GRANT ALL PRIVILEGES ON `uuism\_whmcs`.* TO 'uuism'@'65.18.196.199';
+GRANT ALL PRIVILEGES ON `uuism\_mw1980`.* TO 'uuism'@'65.18.196.199';
 GRANT ALL PRIVILEGES ON `uuism\_net\_wikidb`.* TO 'uuism'@'65.18.196.199';
 GRANT USAGE ON *.* TO 'uuism'@'host2.uuserver.net' IDENTIFIED BY PASSWORD '*4DAF2F2129D8E11A627F7BBD9BB97CE832DFC325';
 GRANT ALL PRIVILEGES ON `uuism\_joom675`.* TO 'uuism'@'host2.uuserver.net';
@@ -65,15 +65,15 @@ GRANT USAGE ON *.* TO 'uuism'@'host4.uuserver.net' IDENTIFIED BY PASSWORD '*4DAF
 GRANT ALL PRIVILEGES ON `cptmpdb\_uuism\_MHMX4VxwNGzwGfz4`.* TO 'uuism'@'host4.uuserver.net';
 GRANT ALL PRIVILEGES ON `uuism\_joom675`.* TO 'uuism'@'host4.uuserver.net';
 GRANT ALL PRIVILEGES ON `uuism\_test`.* TO 'uuism'@'host4.uuserver.net';
-GRANT ALL PRIVILEGES ON `uuism\_mw1980`.* TO 'uuism'@'host4.uuserver.net';
 GRANT ALL PRIVILEGES ON `uuism\_whmcs`.* TO 'uuism'@'host4.uuserver.net';
+GRANT ALL PRIVILEGES ON `uuism\_mw1980`.* TO 'uuism'@'host4.uuserver.net';
 GRANT ALL PRIVILEGES ON `uuism\_net\_wikidb`.* TO 'uuism'@'host4.uuserver.net';
 GRANT USAGE ON *.* TO 'uuism'@'localhost' IDENTIFIED BY PASSWORD '*4DAF2F2129D8E11A627F7BBD9BB97CE832DFC325';
 GRANT ALL PRIVILEGES ON `cptmpdb\_uuism\_MHMX4VxwNGzwGfz4`.* TO 'uuism'@'localhost';
 GRANT ALL PRIVILEGES ON `uuism\_joom675`.* TO 'uuism'@'localhost';
 GRANT ALL PRIVILEGES ON `uuism\_test`.* TO 'uuism'@'localhost';
-GRANT ALL PRIVILEGES ON `uuism\_mw1980`.* TO 'uuism'@'localhost';
 GRANT ALL PRIVILEGES ON `uuism\_whmcs`.* TO 'uuism'@'localhost';
+GRANT ALL PRIVILEGES ON `uuism\_mw1980`.* TO 'uuism'@'localhost';
 GRANT ALL PRIVILEGES ON `uuism\_net\_wikidb`.* TO 'uuism'@'localhost';
 GRANT USAGE ON *.* TO 'uuism_joom675'@'172.31.13.215' IDENTIFIED BY PASSWORD '*B49ECEEA6EC07EA63C406DBB47E66EF8CC6410A7';
 GRANT ALL PRIVILEGES ON `uuism\_joom675`.* TO 'uuism_joom675'@'172.31.13.215';
